summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/autolayout/autolayouter.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
commit3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b (patch)
tree4405f233f4b0eee7f4ad3d265a5584c9ce681011 /umbrello/umbrello/autolayout/autolayouter.cpp
parentd6331f1b56eb6dca7a1950658b2932f208015da0 (diff)
downloadtdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.tar.gz
tdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit d6331f1b56eb6dca7a1950658b2932f208015da0.
Diffstat (limited to 'umbrello/umbrello/autolayout/autolayouter.cpp')
-rw-r--r--umbrello/umbrello/autolayout/autolayouter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/autolayout/autolayouter.cpp b/umbrello/umbrello/autolayout/autolayouter.cpp
index f70fd195..802bc438 100644
--- a/umbrello/umbrello/autolayout/autolayouter.cpp
+++ b/umbrello/umbrello/autolayout/autolayouter.cpp
@@ -13,11 +13,11 @@
***************************************************************************/
#include "autolayouter.h"
-namespace Autolayout {
+namespace Autotqlayout {
-void Autolayouter::autolayout( UMLView * v )
+void Autolayouter::autotqlayout( UMLView * v )
{
setCanvas(v);
setGraph(v);
@@ -25,5 +25,5 @@ void Autolayouter::autolayout( UMLView * v )
updateView(v);
}
-} // end namespace Autolayout
+} // end namespace Autotqlayout